@@ -80,7 +80,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Tony Cox
 
@@ -156,7 +156,7 @@ sub _index_file {
 
     my $id_parser = $self->id_parser;
     my $c = 0;
-    open my $FASTQ, '<', $file or $self->throw("Can't open file for read : $file");
+    open my $FASTQ, '<', $file or $self->throw("Could not read file '$file': $!");
 
     # In Windows, text files have '\r\n' as line separator, but when reading in
     # text mode Perl will only show the '\n'. This means that for a line "ABC\r\n",
