@@ -1,7 +1,8 @@
-# $Id: Physical.pm 11480 2007-06-14 14:16:21Z sendu $
 #
 # BioPerl module for Bio::Map::Physical
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Sendu Bala <bix@sendu.me.uk>
 #
 # Copyright AGCoL
@@ -18,7 +19,7 @@ Bio::Map::Physical - A class for handling a Physical Map (such as FPC)
 
     use Bio::MapIO;
 
-    # accquire a Bio::Map::Physical using Bio::MapIO::fpc
+    # acquire a Bio::Map::Physical using Bio::MapIO::fpc
     my $mapio = Bio::MapIO->new(-format => "fpc",-file => "rice.fpc",
                                -readcor => 0);
 
@@ -78,13 +79,24 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Gaurav Gupta
 
@@ -1115,6 +1127,8 @@ sub _calc_markerposition {
 	@sortedctgmarker = sort { $a->{'contig'} <=> $b->{'contig'}
 				                  ||
 				  $b->{'start'}  <=> $a->{'start'}
+				                  ||
+				  $b->{'end'}    <=> $a->{'end'}
 			        } @ctgmarker;
 				
 	my $ctg = -1;
@@ -1143,7 +1157,7 @@ sub _calc_markerposition {
 		
 		$depth = $save_depth = 1;
 	    }
-	    elsif ($sortedctgmarker[$i] <= $y) {
+	    elsif ($sortedctgmarker[$i]->{'end'} <= $y) {
 		$stack[$depth++] = $sortedctgmarker[$i]->{'end'};
 		# MAX
 		if ($x < $sortedctgmarker[$i]->{'start'} ) {
@@ -1311,4 +1325,4 @@ sub _setContigRef {
     %{$self->{'_contigs'}} = %{$ref};
 }
 
-1;
\ No newline at end of file
+1;
