@@ -1,7 +1,7 @@
 #
 # BioPerl module for Bio::SeqIO::bsml
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Charles Tilford (tilfordc@bms.com)
 # Copyright (C) Charles Tilford 2001
@@ -21,11 +21,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # Also at:   http://www.gnu.org/copyleft/lesser.html
 
-
 # Much of the basic documentation in this module has been
 # cut-and-pasted from the embl.pm (Ewan Birney) SeqIO module.
 
-
 =head1 NAME
 
 Bio::SeqIO::bsml - BSML sequence input/output stream
@@ -78,15 +76,15 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -95,7 +93,7 @@ with code and data examples if at all possible.
  the bugs and their resolution.
  Bug reports can be submitted via the web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head2 Things Still to Do
 
@@ -164,13 +162,16 @@ my $nvtoken = ": ";  # The token used if a name/value pair has to be stuffed
 
 =cut
 
-# LS: this seems to get overwritten on line 1317, generating a redefinition error.  Dead code?
-# CAT: This was inappropriately added in revision 1.10 - I added the check for existance of a sequence factory to the actual _initialize
+# LS: this seems to get overwritten on line 1317, generating a redefinition error.
+# Dead code?
+# CAT: This was inappropriately added in revision 1.10 - I added the check for
+# existence of a sequence factory to the actual _initialize
 # sub _initialize {
 #   my($self,@args) = @_;
 #   $self->SUPER::_initialize(@args);
 #   if( ! defined $self->sequence_factory ) {
-#       $self->sequence_factory(Bio::Seq::SeqFactory->new(-verbose => $self->verbose(), -type => 'Bio::Seq::RichSeq'));
+#       $self->sequence_factory(Bio::Seq::SeqFactory->new(-verbose => $self->verbose(),
+#         -type => 'Bio::Seq::RichSeq'));
 #   }
 # }
 
@@ -247,7 +248,7 @@ sub next_seq {
     my %specs = ('common_name' => 'y',
 		 'genus'       => 'y',
 		 'species'     => 'y',
-		 'sub_species' => 'y', 
+		 'sub_species' => 'y',
 		 );
     my %seqMap = (
 		  'add_date'     => [ qw(date date-created date-last-updated)],
@@ -281,7 +282,7 @@ sub next_seq {
 		$value ||= $content if ($name =~ /$match/i);
 	    }
 	    if ($value ne "") {
-		
+
 		if( $method eq 'seq_version'&& $value =~ /\S+\.(\d+)/ ) {
 		    # hack for the fact that data in version is actually
 		    # ACCESSION.VERSION
@@ -355,30 +356,29 @@ sub next_seq {
 		-location => "RefJournal",
 		);
     for my $ref ( $xmlSeq->getElementsByTagName ("Reference") ) {
-	my %refVals;
-	for my $tag (keys %tags) {
-	    my $rt = &FIRSTDATA($ref->getElementsByTagName($tags{$tag})
-				->item(0));
-	    next unless ($rt);
-	    $rt =~ s/^[\s\r\n]+//; # Kill leading space
-	    $rt =~ s/[\s\r\n]+$//; # Kill trailing space
-	    $rt =~ s/[\s\r\n]+/ /; # Collapse internal space runs
-	    $refVals{$tag} = $rt;
-	}
+		my %refVals;
+		for my $tag (keys %tags) {
+	    	my $rt = &FIRSTDATA($ref->getElementsByTagName($tags{$tag})->item(0));
+	    	next unless ($rt);
+	    	$rt =~ s/^[\s\r\n]+//; # Kill leading space
+	    	$rt =~ s/[\s\r\n]+$//; # Kill trailing space
+	    	$rt =~ s/[\s\r\n]+/ /; # Collapse internal space runs
+	    	$refVals{$tag} = $rt;
+		}
 	my $reference = Bio::Annotation::Reference->new( %refVals );
-	
+
 	# Pull out any <Reference> information hidden in <Attributes>
 	my %refMap = (
 		      comment         => [ 'comment', 'remark' ],
 		      medline         => [ 'medline', ],
 		      pubmed          => [ 'pubmed' ],
 		      start           => [ 'start', 'begin' ],
-		      end             => [ 'stop', 'end' ],		      
+		      end             => [ 'stop', 'end' ],
 		      );
 	my @refCom = ();
 	my $floppies = &GETFLOPPIES($ref);
 	for my $attr (@{$floppies}) {
-	    my ($name, $content) = &FLOPPYVALS($attr);	    
+	    my ($name, $content) = &FLOPPYVALS($attr);
 	    my $value = "";
 	    # Cycle through the Seq methods:
 	    for my $method (keys %refMap) {
@@ -412,12 +412,12 @@ sub next_seq {
     for my $feat ( $xmlSeq->getElementsByTagName("Feature") ) {
 	$bioSeq->add_SeqFeature( $self->_parse_bsml_feature($feat) );
     }
-    
+
     $species->classification( @classification );
     $bioSeq->species( $species );
-    
+
     $bioSeq->annotation->add_Annotation('dblink' => $_) for @links;
-    
+
     $self->{'current_node'}++;
     return $bioSeq;
 }
@@ -611,7 +611,12 @@ sub to_bsml {
 	my $seqRefs = []; my $featRefs = [];
 	# Array references to hold <Attribute> values (not objects):
 	my $seqDesc = [];
-	push @{$seqDesc}, ["comment" , "This file generated to BSML 2.2 standards - joins will be collapsed to a single feature enclosing all members of the join"];
+    push @{$seqDesc},
+    [
+    "comment",
+    "This file generated to BSML 2.2 standards - " .
+    "joins will be collapsed to a single feature enclosing all members of the join"
+    ];
 	push @{$seqDesc}, ["description" , eval{$bioSeq->desc}];
 	for my $kwd ( eval{$bioSeq->get_keywords} ) {
 	    push @{$seqDesc}, ["keyword" , $kwd];
@@ -752,7 +757,7 @@ sub to_bsml {
 		next if (defined $args->{SKIPTAGS} &&
 			 $args->{SKIPTAGS} =~ /all/i);
 		# Tags can consume a lot of CPU cycles, and can often be
-		# rather non-informative, so -skiptags can allow total or
+		# rather non-informative, so -skiptags can allow one total or
 		# selective omission of tags.
 		for my $tag ($bioFeat->all_tags()) {
 		    next if (exists $args->{SKIPTAGS}{$tag});
@@ -836,7 +841,7 @@ sub to_bsml {
            document, where $mimetype is the value designated by this
            key. For generic XML use text/xml, for BSML use text/x-bsml
 
-   -return This option will be supressed, since the nature of this
+   -return This option will be suppressed, since the nature of this
            method is to print out the XML document. If you wish to
            retrieve the <Sequence> objects generated, use the to_bsml
            method directly.
@@ -999,7 +1004,7 @@ sub _parse_bsml_feature {
     for my $attr (@{$floppies}) {
 	my ($name, $content) = &FLOPPYVALS($attr);
 	# Don't know what the object is, dump it to a tag:
-	$basegsf->add_tag_value(lc($name), $content);	
+	$basegsf->add_tag_value(lc($name), $content);
     }
 
     # Mostly this helps with debugging, but may be of utility...
