@@ -111,7 +111,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.
 Bug reports can be submitted via the web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Chris Mungall
 
@@ -367,7 +367,7 @@ sub write_seq {
     } qw(desc keywords division molecule is_circular);
     $prop{dates} = join("; ", $seq->get_dates) if $seq->can("get_dates");
 
-    local($^W) = 0;   # supressing warnings about uninitialized fields.
+    local($^W) = 0;   # suppressing warnings about uninitialized fields.
 
     # Reference lines
     my $count = 1;
